/* GTK NAMED COLORS
   ----------------
   use responsibly! */

// Sass thinks we're using the colors in the variables as strings and may shoot
// warning, it's innocuous and can be defeated by using #{$var}.

// These are the colors apps are can override. 
// Derived from src/stylesheet/_defaults.scss in libadwaita source tree.

// The main accent color and the matching text value
@define-color accent_bg_color #{$selected_bg_color};
@define-color accent_fg_color #{$selected_fg_color};
@define-color accent_color #{$selected_bg_color};

// destructive-action buttons
@define-color destructive_bg_color #{$destructive_color};
@define-color destructive_fg_color #{$destructive_fg_color};
@define-color destructive_color #{$destructive_color};

// Levelbars, entries, labels and infobars. These don't need text colors
@define-color success_bg_color #{$success_color};
@define-color success_fg_color white;
@define-color success_color #{$success_color};

@define-color warning_bg_color #{$warning_color};
@define-color warning_fg_color #{$warning_fg_color};
@define-color warning_color #{$warning_color};

@define-color error_bg_color #{$error_color};
@define-color error_fg_color #{$error_fg_color};
@define-color error_color #{$error_color};

// Window
@define-color window_bg_color #{$base_color};
@define-color window_fg_color #{$text_color};

// Views - e.g. text view or tree view
@define-color view_bg_color #{$bg_color};
@define-color view_fg_color #{$fg_color};

// Header bar, search bar, tab bar
@define-color headerbar_bg_color #{$header_bg};
@define-color headerbar_fg_color #{$header_fg};
@define-color headerbar_border_color #{$header_border};
@define-color headerbar_backdrop_color #{$header_bg_backdrop};
@define-color headerbar_shade_color #{$bg_color};

// Cards, boxed lists
@define-color card_bg_color #{$base_color};
@define-color card_fg_color #{$fg_color};
@define-color card_shade_color #{$base_color};

// Popovers
@define-color popover_bg_color #{if($variant!='dark', $base_color, $bg_color)};
@define-color popover_fg_color #{$fg_color};

// Miscellaneous
@define-color shade_color #{transparentize(black, 0.8)};
@define-color scrollbar_outline_color #{if($variant != 'dark', white, transparentize(black, .5))};

